import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    Edit,
    SimpleForm,
    FormDataConsumer,
    useTranslate,
    TextInput,
    NumberInput,
    BooleanInput,
    DateInput,
    SelectInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    SaveButton,
    Toolbar,
    Labeled,
    NumberField,
    required,
    useRecordContext,
    DeleteButton,
    SelectArrayInput,
} from 'react-admin';
import { useWatch, useFormContext } from "react-hook-form";
import { Stack, Grid, Box, Typography } from '@mui/material';
import * as Common from '@/utils/common';
import { EDIT_MODE, REFERENCE_INPUT_PAGESIZE } from '@/config/setting';
import EditBaseAside from "../../components/EditBaseAside";
import CustomerTopToolBar from "../../components/EditTopToolBar";
import MemoInput from "../../components/MemoInput";
import StatusSelectInput from "../../components/StatusSelectInput";
import DictionarySelect from "../../components/DictionarySelect";
import DictionaryArraySelect from "../../components/DictionaryArraySelect";

const FormToolbar = () => {
    const { getValues } = useFormContext();

    return (
        <Toolbar sx={{ justifyContent: 'space-between' }}>
            <SaveButton />
            <DeleteButton mutationMode="optimistic" />
        </Toolbar>
    )
}

const BasStationEdit = () => {
    const translate = useTranslate();

    return (
        <Edit
            redirect="list"
            mutationMode={EDIT_MODE}
            actions={<CustomerTopToolBar />}
            aside={<EditBaseAside />}
        >
            <SimpleForm
                shouldUnregister
                warnWhenUnsavedChanges
                toolbar={<FormToolbar />}
                mode="onTouched"
                defaultValues={{}}
            // validate={(values) => { }}
            >
                <Grid container width={{ xs: '100%', xl: '80%' }} rowSpacing={3} columnSpacing={3}>
                    <Grid item xs={12} md={8}>
                        <Typography variant="h6" gutterBottom>
                            {translate('common.edit.title.main')}
                        </Typography>
                        <Stack direction='row' gap={2}>
                            <TextInput
                                label="table.field.basStation.stationName"
                                source="stationName"
                                parse={v => v}
                                autoFocus
                            />
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <SelectInput
                                    label="table.field.basStation.inAble"
                                    source="inAble"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                            />
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <SelectInput
                                    label="table.field.basStation.outAble"
                                    source="outAble"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                            />
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <DictionarySelect
                                label={translate("table.field.basStation.useStatus")}
                                name="useStatus"
                                size="small"
                                validate={[required()]}
                                dictTypeCode="sys_sta_use_stas"
                            />
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <ReferenceInput source="area" reference="warehouseAreas">
                                <SelectInput 
                                    label="table.field.basStation.area"
                                    optionText="name"
                                    optionValue="id"
                                    fullWidth  
                                    validate={[required()]}     
                                />
                            </ReferenceInput>
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <SelectInput
                                    label="table.field.basStation.isCrossZone"
                                    source="isCrossZone"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                                    validate={[required()]}
                            />
                        </Stack>
                        <Stack direction='row' gap={2}> 
                            <ReferenceArrayInput source="areaIds" reference="warehouseAreas">
                                <SelectArrayInput 
                                    label="table.field.basStation.crossZoneArea"
                                    optionText="name"
                                    optionValue="id"
                                    fullWidth       
                                />
                            </ReferenceArrayInput>                             
                        </Stack>
                        <Stack direction='row' gap={2}>                            
                            <SelectInput
                                    label="table.field.basStation.isWcs"
                                    source="isWcs"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                                    validate={[required()]}
                            />
                        </Stack>                        
                        <Stack direction='row' gap={2}>                            
                            <DictionaryArraySelect
                                label={translate("table.field.basStation.containerType")}
                                name="containerTypes"
                                size="small"
                                validate={[required()]}
                                dictTypeCode="sys_container_type"
                            />
                        </Stack>                        
                        <Stack direction='row' gap={2}>                            
                            <SelectInput
                                    label="table.field.basStation.autoTransfer"
                                    source="autoTransfer"
                                    choices={[
                                        { id: 0, name: '否' },
                                        { id: 1, name: '是' },
                                    ]}
                            />
                        </Stack>

                    </Grid>
                    <Grid item xs={12} md={4}>
                        <Typography variant="h6" gutterBottom>
                            {translate('common.edit.title.common')}
                        </Typography>
                        <StatusSelectInput />
                        <Box mt="2em" />
                        <MemoInput />
                    </Grid>
                </Grid>
            </SimpleForm>
        </Edit >
    )
}

export default BasStationEdit;
